@@ -584,7 +584,7 @@ class SnowflakeSourceConnector(C8Connector):
     def config(self) -> list[ConfigProperty]:
         """Get configuration parameters for the connector."""
         return [
-            ConfigProperty('acccount', 'Account', ConfigAttributeType.STRING, True, False,
+            ConfigProperty('account', 'Account', ConfigAttributeType.STRING, True, False,
                            description='Snowflake account',
                            placeholder_value='snowflake_account'),
             ConfigProperty('dbname', 'Database Name', ConfigAttributeType.STRING, True, False,
